pub struct BlendedNoise {
min_limit_noise: PerlinNoise,
max_limit_noise: PerlinNoise,
main_noise: PerlinNoise,
xz_multiplier: f64,
y_multiplier: f64,
xz_factor: f64,
y_factor: f64,
smear_scale_multiplier: f64,
max_value: f64,
}Expand description
Runtime BlendedNoise sampler with three seeded PerlinNoise instances.
Matches vanilla’s BlendedNoise density function.
Fields
min_limit_noise: PerlinNoisemax_limit_noise: PerlinNoisemain_noise: PerlinNoisexz_multiplier: f64y_multiplier: f64xz_factor: f64y_factor: f64smear_scale_multiplier: f64max_value: f64Implementations
Sourceimpl BlendedNoise
impl BlendedNoise
Sourcepub fn new(
random: &mut RandomSource,
xz_scale: f64,
y_scale: f64,
xz_factor: f64,
y_factor: f64,
smear_scale_multiplier: f64,
) -> Self
pub fn new( random: &mut RandomSource, xz_scale: f64, y_scale: f64, xz_factor: f64, y_factor: f64, smear_scale_multiplier: f64, ) -> Self
Create a new BlendedNoise from a random source and scale parameters.
This matches vanilla’s BlendedNoise(RandomSource, ...) constructor which
uses the legacy initialization path with createLegacyForBlendedNoise.
Sourcepub fn compute(&self, block_x: f64, block_y: f64, block_z: f64) -> f64
pub fn compute(&self, block_x: f64, block_y: f64, block_z: f64) -> f64
Compute the blended noise value at the given block coordinates.
Sourcepub fn compute_simd<const N: usize>(
&self,
block_x: f64,
block_ys: [f64; N],
block_z: f64,
) -> [f64; N]
pub fn compute_simd<const N: usize>( &self, block_x: f64, block_ys: [f64; N], block_z: f64, ) -> [f64; N]
Compute blended noise for N points sharing the same (x, z) but with different y values. Returns results as an array.
This uses SIMD to vectorize the math-heavy portions (gradient dots, smoothstep, trilinear lerp) across the N Y lanes, while sharing the x/z coordinate work.